FSharp.Azure.Cosmos 1.1.0

Edit this page

FeedIteratorExtensions Module

Type extensions

Type extension Description

this.AsAsyncEnumerable

Full Usage: this.AsAsyncEnumerable

Parameters:
Returns: IAsyncEnumerable<'T>

Converts the iterator to an async sequence of items, spanning every page.

Extended Type: FeedIterator

cancellationToken : CancellationToken

Checked between items and honored by GetAsyncEnumerator only when it is not the default - see FeedIteratorAsyncEnumerable{T} for what happens when a token is supplied to GetAsyncEnumerator instead (for example via WithCancellation).

Returns: IAsyncEnumerable<'T>